@@ -13,6 +13,7 @@
 import re
 import abc
 import warnings
+from copy import deepcopy
 from posixpath import normpath
 
 import six
@@ -32,37 +33,65 @@ from .common import (
 # Map of common protocols, as suggested by the common protocols included in
 # urllib/parse.py, to their default ports. Protocol scheme strings are
 # lowercase.
+#
+# TODO(Ans): Is there a public map of schemes to their default ports? If not,
+# create one? Best I (Ansgar) could find is
+#
+#   https://gist.github.com/mahmoud/2fe281a8daaff26cfe9c15d2c5bf5c8b
+#
 DEFAULT_PORTS = {
-    'ws': 80,
+    'acap': 674,
+    'afp': 548,
+    'dict': 2628,
+    'dns': 53,
     'ftp': 21,
     'git': 9418,
+    'gopher': 70,
     'hdl': 2641,
+    'http': 80,
+    'https': 443,
+    'imap': 143,
+    'ipp': 631,
+    'ipps': 631,
+    'irc': 194,
+    'ircs': 6697,
+    'ldap': 389,
+    'ldaps': 636,
+    'mms': 1755,
+    'msrp': 2855,
+    'mtqp': 1038,
     'nfs': 111,
+    'nntp': 119,
+    'nntps': 563,
+    'pop': 110,
+    'prospero': 1525,
+    'redis': 6379,
+    'rsync': 873,
+    'rtsp': 554,
+    'rtsps': 322,
+    'rtspu': 5005,
+    'sftp': 22,
     'sip': 5060,
+    'sips': 5061,
+    'smb': 445,
+    'snews': 563,
+    'snmp': 161,
     'ssh': 22,
     'svn': 3690,
-    'wss': 443,
-    'http': 80,
-    'imap': 143,
-    'nntp': 119,
-    'sftp': 22,
-    'sips': 5061,
-    'tftp': 69,
-    'rtsp': 554,
-    'wais': 210,
-    'https': 443,
-    'rsync': 873,
-    'rtspu': 5004,
-    'snews': 563,
-    'gopher': 70,
     'telnet': 23,
-    'prospero': 191,
+    'tftp': 69,
+    'ventrilo': 3784,
+    'vnc': 5900,
+    'wais': 210,
+    'ws': 80,
+    'wss': 443,
+    'xmpp': 5222,
 }
 
 
-def lget(l, index, default=None):
+def lget(lst, index, default=None):
     try:
-        return l[index]
+        return lst[index]
     except IndexError:
         return default
 
@@ -601,10 +630,7 @@ class Path(object):
         return not self.isdir
 
     def __truediv__(self, path):
-        copy = self.__class__(
-            path=self.segments,
-            force_absolute=self._force_absolute,
-            strict=self.strict)
+        copy = deepcopy(self)
         return copy.add(path)
 
     def __eq__(self, other):
@@ -959,7 +985,7 @@ class Query(object):
 
         Until furl v0.4.6, the 'delimiter' argument was incorrectly
         spelled 'delimeter'. For backwards compatibility, accept both
-        the correct 'delimiter' and the old, mispelled 'delimeter'.
+        the correct 'delimiter' and the old, misspelled 'delimeter'.
 
         Keys and values are encoded application/x-www-form-urlencoded if
         <quote_plus> is True, percent-encoded otherwise.
@@ -1524,16 +1550,19 @@ class furl(URLPathCompositionInterface, QueryCompositionInterface,
 
     @origin.setter
     def origin(self, origin):
-        toks = origin.split('://', 1)
-        if len(toks) == 1:
-            host_port = origin
+        if origin is None:
+            self.scheme = self.netloc = None
         else:
-            self.scheme, host_port = toks
+            toks = origin.split('://', 1)
+            if len(toks) == 1:
+                host_port = origin
+            else:
+                self.scheme, host_port = toks
 
-        if ':' in host_port:
-            self.host, self.port = host_port.split(':', 1)
-        else:
-            self.host = host_port
+            if ':' in host_port:
+                self.host, self.port = host_port.split(':', 1)
+            else:
+                self.host = host_port
 
     @property
     def url(self):
@@ -1592,11 +1621,11 @@ class furl(URLPathCompositionInterface, QueryCompositionInterface,
 
         return self
 
-    def set(self, args=_absent, path=_absent, fragment=_absent, scheme=_absent,
-            netloc=_absent, origin=_absent, fragment_path=_absent,
-            fragment_args=_absent, fragment_separator=_absent, host=_absent,
-            port=_absent, query=_absent, query_params=_absent,
-            username=_absent, password=_absent):
+    def set(self, args=_absent, path=_absent, fragment=_absent, query=_absent,
+            scheme=_absent, username=_absent, password=_absent, host=_absent,
+            port=_absent, netloc=_absent, origin=_absent, query_params=_absent,
+            fragment_path=_absent, fragment_args=_absent,
+            fragment_separator=_absent):
         """
         Set components of a url and return this furl instance, <self>.
 
@@ -1725,9 +1754,10 @@ class furl(URLPathCompositionInterface, QueryCompositionInterface,
         return self
 
     def remove(self, args=_absent, path=_absent, fragment=_absent,
-               query=_absent, query_params=_absent, port=False,
-               fragment_path=_absent, fragment_args=_absent, username=False,
-               password=False):
+               query=_absent, scheme=False, username=False, password=False,
+               host=False, port=False, netloc=False, origin=False,
+               query_params=_absent, fragment_path=_absent,
+               fragment_args=_absent):
         """
         Remove components of this furl's URL and return this furl
         instance, <self>.
@@ -1756,12 +1786,21 @@ class furl(URLPathCompositionInterface, QueryCompositionInterface,
           password: If True, remove the password, if it exists.
         Returns: <self>.
         """
+        if scheme is True:
+            self.scheme = None
         if username is True:
             self.username = None
         if password is True:
             self.password = None
+        if host is True:
+            self.host = None
         if port is True:
             self.port = None
+        if netloc is True:
+            self.netloc = None
+        if origin is True:
+            self.origin = None
+
         if path is not _absent:
             self.path.remove(path)
 
